@@ -820,25 +820,36 @@ class _WebEnginePermissions(QObject):
     def _on_feature_permission_requested(self, url, feature):
         """Ask the user for approval for geolocation/media/etc.."""
         page = self._widget.page()
+        grant_permission = functools.partial(
+            page.setFeaturePermission, url, feature,
+            QWebEnginePage.PermissionGrantedByUser)
+        deny_permission = functools.partial(
+            page.setFeaturePermission, url, feature,
+            QWebEnginePage.PermissionDeniedByUser)
 
         if feature not in self._options:
             log.webview.error("Unhandled feature permission {}".format(
                 debug.qenum_key(QWebEnginePage, feature)))
-            page.setFeaturePermission(url, feature,
-                                      QWebEnginePage.PermissionDeniedByUser)
+            deny_permission()
             return
 
-        yes_action = functools.partial(
-            page.setFeaturePermission, url, feature,
-            QWebEnginePage.PermissionGrantedByUser)
-        no_action = functools.partial(
-            page.setFeaturePermission, url, feature,
-            QWebEnginePage.PermissionDeniedByUser)
+        if (
+                hasattr(QWebEnginePage, 'DesktopVideoCapture') and
+                feature in [QWebEnginePage.DesktopVideoCapture,
+                            QWebEnginePage.DesktopAudioVideoCapture] and
+                qtutils.version_check('5.13', compiled=False) and
+                not qtutils.version_check('5.13.2', compiled=False)
+        ):
+            # WORKAROUND for https://bugreports.qt.io/browse/QTBUG-78016
+            log.webview.warning("Ignoring desktop sharing request due to "
+                                "crashes in Qt < 5.13.2")
+            deny_permission()
+            return
 
         question = shared.feature_permission(
             url=url.adjusted(QUrl.RemovePath),
             option=self._options[feature], msg=self._messages[feature],
-            yes_action=yes_action, no_action=no_action,
+            yes_action=grant_permission, no_action=deny_permission,
             abort_on=[self._tab.abort_questions])
 
         if question is not None:
@@ -1352,13 +1363,22 @@ class WebEngineTab(browsertab.AbstractTab):
     def _error_page_workaround(self, html):
         """Check if we're displaying a Chromium error page.
 
-        This gets only called if we got loadFinished(False) without JavaScript,
-        so we can display at least some error page.
+        This gets called if we got a loadFinished(False), so we can display at
+        least some error page in situations where Chromium's can't be
+        displayed.
 
         WORKAROUND for https://bugreports.qt.io/browse/QTBUG-66643
+        WORKAROUND for https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=882805
+
         Needs to check the page content as a WORKAROUND for
         https://bugreports.qt.io/browse/QTBUG-66661
         """
+        js_enabled = self.settings.test_attribute('content.javascript.enabled')
+        missing_jst = 'jstProcess(' in html and 'jstProcess=' not in html
+
+        if js_enabled and not missing_jst:
+            return
+
         match = re.search(r'"errorCode":"([^"]*)"', html)
         if match is None:
             return
@@ -1388,8 +1408,7 @@ class WebEngineTab(browsertab.AbstractTab):
         else:
             self._update_load_status(ok)
 
-        js_enabled = self.settings.test_attribute('content.javascript.enabled')
-        if not ok and not js_enabled:
+        if not ok:
             self.dump_async(self._error_page_workaround)
 
         if ok and self._reload_url is not None:
