@@ -1,6 +1,6 @@
 # vim: ft=python fileencoding=utf-8 sts=4 sw=4 et:
 
-# Copyright 2014-2018 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
+# Copyright 2014-2019 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
 #
 # This file is part of qutebrowser.
 #
@@ -42,8 +42,6 @@ class RegistryUnavailableError(Exception):
 
     """Exception raised when a certain registry does not exist yet."""
 
-    pass
-
 
 class NoWindow(Exception):
 
@@ -171,7 +169,7 @@ def _get_tab_registry(win_id, tab_id):
 
     if tab_id == 'current':
         tabbed_browser = get('tabbed-browser', scope='window', window=win_id)
-        tab = tabbed_browser.currentWidget()
+        tab = tabbed_browser.widget.currentWidget()
         if tab is None:
             raise RegistryUnavailableError('window')
         tab_id = tab.tab_id
@@ -306,6 +304,5 @@ def window_by_index(idx):
     """Get the Nth opened window object."""
     if not window_registry:
         raise NoWindow()
-    else:
-        key = sorted(window_registry)[idx]
-        return window_registry[key]
+    key = sorted(window_registry)[idx]
+    return window_registry[key]
